package com.ruoyi.system.mapper.projectV2;

import java.util.List;
import com.ruoyi.system.domain.projectV2.ZsyzShqxPz;

/**
 * 招商引资_审核期限_配置Mapper接口
 * 
 * @author ruoyi
 * @date 2023-02-27
 */
public interface ZsyzShqxPzMapper 
{
    /**
     * 查询招商引资_审核期限_配置
     * 
     * @param id 招商引资_审核期限_配置主键
     * @return 招商引资_审核期限_配置
     */
    public ZsyzShqxPz selectZsyzShqxPzById(Long id);

    /**
     * 查询招商引资_审核期限_配置列表
     * 
     * @param zsyzShqxPz 招商引资_审核期限_配置
     * @return 招商引资_审核期限_配置集合
     */
    public List<ZsyzShqxPz> selectZsyzShqxPzList(ZsyzShqxPz zsyzShqxPz);

    /**
     * 新增招商引资_审核期限_配置
     * 
     * @param zsyzShqxPz 招商引资_审核期限_配置
     * @return 结果
     */
    public int insertZsyzShqxPz(ZsyzShqxPz zsyzShqxPz);

    /**
     * 修改招商引资_审核期限_配置
     * 
     * @param zsyzShqxPz 招商引资_审核期限_配置
     * @return 结果
     */
    public int updateZsyzShqxPz(ZsyzShqxPz zsyzShqxPz);

    /**
     * 删除招商引资_审核期限_配置
     * 
     * @param id 招商引资_审核期限_配置主键
     * @return 结果
     */
    public int deleteZsyzShqxPzById(Long id);

    /**
     * 批量删除招商引资_审核期限_配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZsyzShqxPzByIds(Long[] ids);
}
