package com.ruoyi.web.controller.projectV2;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.projectV2.ZsyzShqxPz;
import com.ruoyi.system.service.projectV2.IZsyzShqxPzService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_审核期限_配置Controller
 * 
 * @author ruoyi
 * @date 2023-02-27
 */
@RestController
@RequestMapping("/system/pz")
public class ZsyzShqxPzController extends BaseController
{
    @Autowired
    private IZsyzShqxPzService zsyzShqxPzService;

    /**
     * 查询招商引资_审核期限_配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:pz:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzShqxPz zsyzShqxPz)
    {
        startPage();
        List<ZsyzShqxPz> list = zsyzShqxPzService.selectZsyzShqxPzList(zsyzShqxPz);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_审核期限_配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:pz:export')")
    @Log(title = "招商引资_审核期限_配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZsyzShqxPz zsyzShqxPz)
    {
        List<ZsyzShqxPz> list = zsyzShqxPzService.selectZsyzShqxPzList(zsyzShqxPz);
        ExcelUtil<ZsyzShqxPz> util = new ExcelUtil<ZsyzShqxPz>(ZsyzShqxPz.class);
        util.exportExcel(response, list, "招商引资_审核期限_配置数据");
    }

    /**
     * 获取招商引资_审核期限_配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:pz:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zsyzShqxPzService.selectZsyzShqxPzById(id));
    }

    /**
     * 新增招商引资_审核期限_配置
     */
    @PreAuthorize("@ss.hasPermi('system:pz:add')")
    @Log(title = "招商引资_审核期限_配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzShqxPz zsyzShqxPz)
    {
        return toAjax(zsyzShqxPzService.insertZsyzShqxPz(zsyzShqxPz));
    }

    /**
     * 修改招商引资_审核期限_配置
     */
    @PreAuthorize("@ss.hasPermi('system:pz:edit')")
    @Log(title = "招商引资_审核期限_配置", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody ZsyzShqxPz zsyzShqxPz)
    {
        return toAjax(zsyzShqxPzService.updateZsyzShqxPz(zsyzShqxPz));
    }

    /**
     * 删除招商引资_审核期限_配置
     */
    @PreAuthorize("@ss.hasPermi('system:pz:remove')")
    @Log(title = "招商引资_审核期限_配置", businessType = BusinessType.DELETE)
    @GetMapping(value = "/delete/{id}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzShqxPzService.deleteZsyzShqxPzByIds(ids));
    }
}
